@@ -13,6 +13,7 @@
 #include <stdio.h>
 #include <math.h>
 #include <complex.h>
+#include <string.h>
 #include <fftw3.h>
 #include "mk4_data.h"
 #include "param_struct.h"
@@ -58,7 +59,8 @@ void pcalibrate (struct type_pass *pass,
            q[3],
            ymax,
            ampmax,
-           del_avg;
+           del_avg,
+           pc_amb_center;
         
     complex pc_avg[2][MAX_PCF],
             pc_adj[2],
@@ -78,6 +80,7 @@ void pcalibrate (struct type_pass *pass,
                                     // function prototypes
     int parabola (double *, double, double, double *, double *, double *);
     complex c_mean (complex *, int);
+    double get_sampler_delay (struct type_pass *, int, int, int);
     static fftw_plan fftplan;
     
                                     // pre-calculate fft quantities only once
@@ -147,6 +150,9 @@ void pcalibrate (struct type_pass *pass,
           pc_adj[stn] = 0.0;
           ndelpts = 0;
           del_avg = 0.0;
+                                    // look up sampler-based delay for this freq/pol combo
+          pc_amb_center = get_sampler_delay (pass, fr, stn, ipol);
+
                                     // apply manual or offset pcal phase
           delta_phase[stn] = theta_ion + M_PI * status.pc_offset[fr][stn][ipol] / 180.0;
 
@@ -250,7 +256,7 @@ void pcalibrate (struct type_pass *pass,
                 delay = (indpeak+ymax) / 256.0 / param.pcal_spacing[stn];       
                                     // find corresponding delay in suitable range
                 pc_amb = 1 / param.pcal_spacing[stn];
-                while (delay < sdelay - pc_amb / 2.0)
+                while (delay < sdelay + pc_amb_center - pc_amb / 2.0)
                     delay += pc_amb;
                                     // add in a priori offset to delay for this chan & stn
                 delay += 1e-9 * status.delay_offs[fr][stn];
@@ -345,3 +351,24 @@ complex c_mean (complex *z, int n)
     sum = sum / n;
     return (sum);
     }
+
+// find center of sampler-based pcal ambiguity window based on freq & pol
+
+double get_sampler_delay (struct type_pass *pass, int ifr, int stn, int ipol)
+    {
+    int n;
+    double value;
+
+    value = 0.0;
+                                    // search for sampler string containing freq code
+    for (n=0; n<pass->control.nsamplers; n++)
+        {
+        if (strchr (pass->control.psamplers[n], pass->pass_data[ifr].freq_code))
+            {
+            value = (stn) ? pass->control.sampler_delay[n][ipol].rem
+                          : pass->control.sampler_delay[n][ipol].ref;
+            break;
+            }
+        }
+    return value;
+    }
